Module handler

Module handler 

Contains the definition of the event handler trait as well as some standard implementations for common use cases.

Structs

StatefulEventHandler
An event handler which manages a closure together with some state which can track information over multiple events. The closure is executed with a mutable reference of the state every time an event is received.
StatelessEventHandler
An event handler which manages a simple closure that receives no state except the event argument. The closure is executed every time an event is received.

Traits

EventHandler
A trait for event handlers which can be registered with an event. For comfort, an implementation for Box<dyn EventHandler<A>> is provided.